@@ -88,16 +88,12 @@ class Instance:
 
         self.closeBinaryFormData()
 
-        try:
-            res = requests.post(Instance.endpoint,
-                                headers=self.headers,
-                                cookies=self.cookies,
-                                data=self.body
-                                )
-            res.raise_for_status()
-        except requests.exceptions.HTTPError as err:
-            if err.response.code == 429:
-                print("Too many requests")
+        res = requests.post(Instance.endpoint,
+                            headers=self.headers,
+                            cookies=self.cookies,
+                            data=self.body
+                            )
+        return res.status_code
 
     def update_visibility(self, value):
         self.body = ""
