@@ -48,14 +48,12 @@ class Instance:
 
     def update(self, value):
         self.addEncodedFormData("value", "1,6,2,1,1,1," + value + ",120")
-
-        request = requests.post(Instance.endpoint,
-                                headers=self.headers,
-                                cookies=self.cookies,
-                                data=self.body
-                                )
-
-        request.raise_for_status()
+        res = requests.post(Instance.endpoint,
+                            headers=self.headers,
+                            cookies=self.cookies,
+                            data=self.body
+                            )
+        res.raise_for_status()
 
     def update_visibility(self, value):
         if type(value) != int:
