@@ -51,13 +51,27 @@ class Instance:
         self.addEncodedFormData("type", "multi")
         self.addEncodedFormData("value", value)
 
-        request = requests.post(Instance.endpoint,
+        try:
+            res = requests.post(Instance.endpoint,
                                 headers=self.headers,
                                 cookies=self.cookies,
                                 data=self.body
                                 )
-
-        request.raise_for_status()
+            res.raise_for_status()
+        except requests.exceptions.HTTPError as err:
+            if err.response.status_code == 429:
+                print("Too many requests! Waiting a bit...")
+                time.sleep(5)
+                res = requests.post(Instance.endpoint,
+                                    headers=self.headers,
+                                    cookies=self.cookies,
+                                    data=self.body
+                                    )
+                res.raise_for_status()
+            if err.response.status_code == 400:
+                return print("You tried to send something bad fuck you!")
+            if err.response.status_code == 403:
+                return print("You need to change the Labymod cookie!")
 
     def update_visibility(self, value):
         if type(value) != int:
